@@ -1,3 +1,164 @@
+#' Meta-analayis of RCTs evaluating the effect of AI agents to reduce psychological distress
+#' effects
+#'
+#' @name ai_distress
+#'
+#' @docType data
+#'
+#'
+#' @format A data frame with 21 RCT studies
+#' #' \describe{
+#'   \item{study_id}{Study identifier.}
+#'   \item{TE}{Treatment effect reported; standardized mean difference with
+#'     Hedges small-sample correction (Hedges' g).}
+#'   \item{seTE}{Standard error of \code{TE}, derived from the plotted 95\% confidence interval using \code{seTE = (upper - lower) / (2 * 1.96)}. Confidence intervals are not stored.}
+#'   \item{risk_of_bias}{Overall Risk of Bias assessment reported in the plot (\code{"Low risk of bias"}, \code{"Some concerns"}, \code{"High risk of bias"}).}
+#' }
+#'
+#' @source
+#'
+#' Bleidorn, W., Schwaba, T., Zheng, A., Hopwood, C. J., Sosa, S. S., Roberts, B. W.,
+#' & Briley, D. A. (2022). Personality stability and change: A meta-analysis of
+#' longitudinal studies. Psychological Bulletin, 148(7-8), 588–619.
+#' https://doi.org/10.3037/bul0000365
+#'
+NULL
+
+#' Meta-Analysis: Evolution of Personality Traits over time
+#'
+#' @name personality
+#'
+#' @docType data
+#'
+#' @format A data frame with 52 studies reporting 18 variables:
+#' \describe{
+#'   \item{authoryear}{First author and publication year.}
+#'   \item{country}{Country where the study was performed.}
+#'   \item{female}{Proportion of females in the study.}
+#'   \item{nameMeasure}{Instrument used to measure the personality trait.}
+#'   \item{old}{Whether the study is "newly coded data" or not.}
+#'   \item{trait}{Personality trait measured.}
+#'   \item{N_T1}{Number of participants at T1.}
+#'   \item{N_T2}{Number of participants at T2.}
+#'   \item{age1}{Mean age at T1.}
+#'   \item{age2}{Mean age at T2.}
+#'   \item{lag}{Difference in years between T1 and T2.}
+#'   \item{Mean_T1}{Mean score at T1.}
+#'   \item{SD_T1}{SD at T1.}
+#'   \item{Mean_T2}{Mean score at T2.}
+#'   \item{SD_T2}{SD at T2.}
+#'   \item{r12}{Correlation coefficient between T1 and T2.}
+#'   \item{TE}{Fisher z-transformed correlation.}
+#'   \item{seTE}{Standard error of TE.}
+#' }
+#'
+#' @source
+#' Bleidorn, Wiebke, et al. (2022). Personality stability and change: A meta-analysis
+#' of longitudinal studies. Psychological Bulletin, 148(7-8), 588–619.
+#' doi:10.1037/bul0000365
+#'
+#' @keywords datasets
+#'
+#'
+NULL
+
+
+
+#' Meta-analysis of Cognitive Outcomes in Very Preterm Children
+#'
+#' @name preterm
+#'
+#' @docType data
+#'
+#' @description
+#' This dataset contains study-level data extracted from the systematic review and meta-analysis
+#' Trends Over Time in Cognitive Outcomes of Children Born Very Preterm by Behboodi et al.
+#' (JAMA Pediatrics, 2025). The review synthesizes evidence from observational cohort and matched
+#' studies comparing cognitive outcomes of children born very preterm (VPT) or extremely preterm (EPT)
+#' with children born at full term (FT).
+#'
+#'
+#' @format A data frame with 61 rows and 18 columns. Each row represents a single study included in the meta-analysis.
+#' The columns include:
+#' \describe{
+#'   \item{study}{First author and publication year.}
+#'   \item{n_EPT.VPT}{Number of children born extremely or very preterm.}
+#'   \item{mean_EPT.VPT}{Mean cognitive score in the EPT/VPT group.}
+#'   \item{sd_EPT.VPT}{Standard deviation of cognitive scores in the EPT/VPT group.}
+#'   \item{n_FT}{Number of children born full term.}
+#'   \item{mean_FT}{Mean cognitive score in the full-term group.}
+#'   \item{sd_FT}{Standard deviation of cognitive scores in the full-term group.}
+#'   \item{SMD}{Standardized mean difference (Hedges’ g) comparing EPT/VPT with FT.}
+#'   \item{seSMD}{Standard error of the standardized mean difference.}
+#'   \item{mean_age}{Mean age at cognitive assessment.}
+#'   \item{mean_ga}{Mean gestational age of the study population.}
+#'   \item{mean_bw}{Mean birth weight of the study population.}
+#'   \item{median_birth_year}{Median year of birth of the cohort included in the study.}
+#'   \item{quality}{Methodological quality score based on a modified Newcastle–Ottawa Scale, ranging from 0 to 7, with higher values indicating better study quality.}
+#'   \item{matched}{Indicator of whether the study used a matched design to compare preterm and full-term participants ("yes" or "no").}
+#'   \item{birth_level}{Classification of the preterm subgroup included in the comparison: \code{VPT} for very preterm only, \code{EPT} for extremely preterm only, and \code{VPT_and_EPT} for combined very and extremely preterm groups.}
+#'   \item{country}{Country where the study was conducted.}
+#'   \item{analysis}{Indicator of whether the study contributed data to the primary analysis, secondary analysis, or both, as defined in Behboodi et al.}
+#' }
+#'
+#' @details
+#' The standardized mean difference (SMD) is a measure of the difference between two group
+#' means, expressed in units of their pooled standard deviation. In this dataset it quantifies the
+#' difference in mean cognitive test scores between children born preterm (EPT/VPT) and those born
+#' full term (FT), with negative values indicating lower scores in the preterm group.
+#'
+#' The SMD is calculated as Hedges’ g. First, Cohen’s d is computed as
+#'
+#' \deqn{d = \frac{\bar{X}_{EPT.VPT} - \bar{X}_{FT}}{s_p},}
+#'
+#' where \eqn{\bar{X}_{EPT.VPT}} and \eqn{\bar{X}_{FT}} are the mean cognitive scores in the EPT/VPT and
+#' FT groups, respectively, and \eqn{s_p} is the pooled standard deviation.
+#'
+#' The pooled standard deviation is given by
+#'
+#' \deqn{s_p =
+#' \sqrt{\frac{(n_{EPT.VPT}-1)\, s_{EPT.VPT}^2 + (n_{FT}-1)\, s_{FT}^2}
+#' {n_{EPT.VPT} + n_{FT} - 2}}.}
+#'
+#' Here, \eqn{n_{EPT.VPT}} and \eqn{n_{FT}} are the group sample sizes, and
+#' \eqn{s_{EPT.VPT}} and \eqn{s_{FT}} are the corresponding standard deviations.
+#'
+#' Cohen’s d is multiplied by the small-sample correction factor
+#'
+#' \deqn{J = 1 - \frac{3}{4\,(n_{EPT.VPT} + n_{FT} - 2) - 1}}
+#'
+#' to obtain Hedges’ g:
+#'
+#' \deqn{SMD = g = J \times d.}
+#'
+#' The standard error of the standardized mean difference (seSMD) measures the uncertainty of the
+#' estimated SMD. Smaller values indicate more precise estimates of the difference between the
+#' preterm (EPT/VPT) and full-term (FT) groups.
+#'
+#' The seSMD is calculated as
+#'
+#' \deqn{seSMD =
+#' \sqrt{
+#' J^2 \left(
+#' \frac{n_{EPT.VPT} + n_{FT}}{n_{EPT.VPT}\, n_{FT}}
+#' +
+#' \frac{d^2}{2\,(n_{EPT.VPT} + n_{FT} - 2)}
+#' \right)
+#' }.}
+#'
+#'
+#' @source
+#' Behboodi S, Chaimani A, Benhammou V, Twilhaar ES, Johnson S, Zeitlin J, Sentenac M.
+#' Trends Over Time in Cognitive Outcomes of Children Born Very Preterm:
+#' A Systematic Review and Meta-Analysis. JAMA Pediatrics. 2025;179(10):1074–1081.
+#' doi:10.1001/jamapediatrics.2025.2221.
+#'
+#' @keywords datasets
+#'
+NULL
+
+#'
+#'
 #' Meta-analysis: Long-COVID Health Outcomes
 #'
 #' @name longcovid
@@ -429,14 +590,15 @@ NULL
 #'
 #' @description
 #'
-#' Meta-analysis of 83 studies comparing 12-month visual acuity change results in routine clinical practices
+#' Meta-analysis of 82 studies comparing 12-month visual acuity change results in routine clinical practices
 #' of intravitreal therapy for diabetic maculaedema (DME) to the change in RCTs by pooling data published in the
 #' last decade on treated eyes of treatment effect from OS.
 #'
-#' @format  A dataframe with 83 rows and 13 columns. Each row represents study results, the columns are:
+#' @format  A dataframe with 83 rows and 24 columns. Each row represents study results, the columns are:
 #'    \describe{
 #'     \item{therapy}{Used Medication}
 #'     \item{author_year}{Author and year.}
+#'     \item{study_design}{Study type/Design}
 #'     \item{eyes}{Number of tested eyes.}
 #'     \item{TE}{Mean Change in Visual Acuity after 12-Months. Where Visual Acuity is measured in VAR (Visual Acuity Rating) score}
 #'     \item{seTE}{Standard Error of the Treatment Effect}
@@ -444,10 +606,20 @@ NULL
 #'     \item{upper_95pct_ci}{Upper 95prc CI for TE}
 #'     \item{number_of_patients_at_baseline}{Number of Patients in Study at Baseline}
 #'     \item{mean_age}{The mean age of patients per study}
+#'     \item{sd_age}{The standard deviation of age of patients per study}
+#'     \item{se_age}{The standard error of age of patients per study}
 #'     \item{baseline_va}{Mean Visual Acuity at Baseline. Where Visual Acuity is measured in VAR (Visual Acuity Rating) score}
+#'     \item{sd_baseline_va}{The standard deviation of Visual Acuity at Baseline. Where Visual Acuity is measured in VAR (Visual Acuity Rating) score}
+#'     \item{se_baseline_va}{The standard error of Visual Acuity at Baseline. Where Visual Acuity is measured in VAR (Visual Acuity Rating) score}
 #'     \item{12_month_va}{Mean Visual Acuity after 12 months. Where Visual Acuity is measured in VAR (Visual Acuity Rating) score}
+#'     \item{sd_12_month_va}{The standard deviation of Visual Acuity after 12 months. Where Visual Acuity is measured in VAR (Visual Acuity Rating) score}
+#'     \item{se_12_month_va}{The standard error of Visual Acuity after 12 months. Where Visual Acuity is measured in VAR (Visual Acuity Rating) score}
 #'     \item{baseline_cst}{Mean Central Subfield Thickness at Baseline}
+#'     \item{sd_baseline_cst}{The standard deviation of Central Subfield Thickness at Baseline}
+#'     \item{se_baseline_cst}{The standard error of Central Subfield Thickness at Baseline}
 #'     \item{12_month_cst}{Mean Central Subfield Thickness after 12 months}
+#'     \item{sd_12_month_cst}{The standard deviation of Central Subfield Thickness after 12 months}
+#'     \item{se_12_month_cst}{The standard error of Central Subfield Thickness after 12 months}
 #'     }
 #'
 #' @source Mehta H, Nguyen V, Barthelmes D, Pershing S, Chi GC, Dopart P, Gillies MC. Outcomes of Over 40,000 Eyes Treated for Diabetic Macula Edema in Routine Clinical Practice: A Systematic Review and Meta-analysis. Adv Ther. 2022 Dec;39(12):5376-5390. doi: 10.1007/s12325-022-02326-8. Epub 2022 Oct 15. PMID: 36241963; PMCID: PMC9618488.
@@ -457,6 +629,12 @@ NULL
 #' @keywords datasets
 #'
 #'
+#'
+
+
+
+
+
 
 NULL
 
