@@ -145,7 +145,10 @@ dpmeta.default = function(
                 "sd.0",
                 "p",
                 "alpha",
-                "gind")
+                "gind",
+                "group",
+                "equalsmatrix"
+               )
 
   # Model in BUGS
   model.bugs <-
@@ -167,6 +170,14 @@ dpmeta.default = function(
 
            }
 
+# Number of studies in the same bias cluster
+  for(i in 1:N){
+    for(j in 1:N){
+    equalsmatrix[i,j] <- equals(group[i], group[j])
+    }
+  }
+
+
   # Stick-Breaking process and sampling from G0...............
              q[1] ~ dbeta(1, alpha)
              p[1] <- q[1]
